| find_all_station_names | R Documentation |
For IMGW-PIB stations different naming were used historically. For example,
POZNAŃ and “POZNAŃ-ŁAWICA, thus both names should be used when searching
for the station. This function finds all variants of station' names
status information and expand the created object
find_all_station_names(station_name)
station_name |
character vector of station names |
character vector of station names with all variants of station's names
{
find_all_station_names(c("WARSZAWA", "POZNAŃ"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.