hydro_imgw: Hydrological data from IMGW

View source: R/hydro_imgw.R

hydro_imgwR Documentation

Hydrological data from IMGW

Description

Downloading daily, and monthly hydrological data from the measurement stations available in the danepubliczne.imgw.pl collection

Usage

hydro_imgw(interval, year, value = "H", station = NULL, ...)

Arguments

interval

temporal resolution of the data ("daily" or "monthly")

year

vector of years (e.g., 1966:2000)

value

type of data (can be: state - "H" (default), flow - "Q", or temperature - "T")

station

vector of hydrological stations danepubliczne.imgw.pl; can be given as station name with CAPITAL LETTERS (character) It accepts either names (characters in CAPITAL LETTERS) or stations' IDs (numeric)

...

other parameters that may be passed e.g. to the 'shortening' function that shortens column names

Value

A data.frame with columns describing the hydrological parameters (e.g. flow, water level) where each row represent a measurement, depending on the interval, at a given hour, month or year. IMGW parameter columns carry a label attribute with the original metadata label. If coords = TRUE additional two columns with geographic coordinates are added.

Examples


  x = hydro_imgw("monthly", year = 1999)
  head(x)


climate documentation built on Sept. 18, 2026, 5:06 p.m.