hydro_imgw_daily: Daily hydrological data

View source: R/hydro_imgw_daily.R

hydro_imgw_dailyR Documentation

Daily hydrological data

Description

Downloading daily hydrological data from the danepubliczne.imgw.pl collection

Usage

hydro_imgw_daily(year, station = NULL, allow_failure = TRUE, ...)

Arguments

year

vector of years (e.g., 1966:2000)

station

name or ID of hydrological station(s). It accepts names (characters in CAPITAL LETTERS) or stations' IDs (numeric)

allow_failure

logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE

...

other parameters that may be passed to the 'shortening' function that shortens column names

Value

data.frame with historical hydrological data for the daily time interval

Examples


  daily = hydro_imgw_daily(year = 2000)



climate documentation built on Sept. 18, 2026, 5:06 p.m.