View source: R/meteo_imgw_hourly.R
| meteo_imgw_hourly | R Documentation |
Downloading hourly (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection
meteo_imgw_hourly(
rank = "synop",
year,
status = FALSE,
coords = FALSE,
station = NULL,
allow_failure = TRUE,
...
)
rank |
rank of the stations: "synop" (default), "climate", or "precip" |
year |
vector of years (e.g., 1966:2000) |
status |
leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted) |
coords |
add coordinates of the station (logical value TRUE or FALSE) |
station |
name of meteorological station(s) (character vector) |
allow_failure |
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE |
... |
other parameters that may be passed to the 'shortening' function that shortens column names |
meteorological data for the hourly time interval
hourly = meteo_imgw_hourly(rank = "climate", year = 1984)
head(hourly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.