R/meteo_shortening_imgw.R
meteo_shortening_imgw.RdShortening column names of meteorological parameters to improve the readability of downloaded dataset from the danepubliczne.imgw.pl collection and removing duplicated column names
meteo_shortening_imgw(data, col_names = "short", remove_duplicates = TRUE)downloaded dataset with original column names
three types of column names possible: "short" - default, values with shorten names, "full" - full English description, "polish" - original names in the dataset
whether to remove duplicated column names (default TRUE - i.e., columns with duplicated names are deleted)
data.frame with modified names of meteorological parameters
# \donttest{
monthly = meteo_imgw("monthly", rank = "climate", year = 1969)
#> Your system locale is: C.UTF-8 which may cause trouble.
#> Please consider changing it manually while working with climate, e.g.:
#> Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8')
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/1966_1970/1966_1970_m_k.zip
abbr = meteo_shortening_imgw(data = monthly,
col_names = "full",
remove_duplicates = TRUE)
head(abbr)
#> id station yy mm Absolutna maksymalna temperatura powietrza [°C]
#> 1 249180010 PSZCZYNA 1969 1 9.5
#> 2 249180010 PSZCZYNA 1969 2 7.4
#> 3 249180010 PSZCZYNA 1969 3 11.4
#> 4 249180010 PSZCZYNA 1969 4 27.5
#> 5 249180010 PSZCZYNA 1969 5 30.0
#> 6 249180010 PSZCZYNA 1969 6 28.9
#> Srednia maksymalna temperatura powietrza [°C]
#> 1 -1.3
#> 2 0.4
#> 3 2.5
#> 4 13.1
#> 5 21.3
#> 6 20.9
#> Absolutna minimalna temperatura powietrza [°C]
#> 1 -20.0
#> 2 -16.6
#> 3 -10.6
#> 4 -4.4
#> 5 2.0
#> 6 6.1
#> Srednia minimalna temperatura powietrza [°C]
#> 1 -9.3
#> 2 -4.7
#> 3 -3.5
#> 4 2.0
#> 5 9.0
#> 6 10.5
#> Srednia miesieczna temperatura powietrza [°C]
#> 1 -5.1
#> 2 -2.3
#> 3 -0.8
#> 4 7.1
#> 5 14.8
#> 6 15.4
#> Minimalna temperatura powietrza przy gruncie [°C] rr_monthly
#> 1 -22.4 34.9
#> 2 -17.5 47.2
#> 3 -11.3 44.8
#> 4 -6.2 15.7
#> 5 -0.1 69.2
#> 6 4.4 101.2
#> Maksymalna dobowa suma opadow w miesiacu [mm] first_day_max_rr
#> 1 12.0 23
#> 2 15.9 8
#> 3 10.1 11
#> 4 4.0 1
#> 5 30.0 29
#> 6 35.0 21
#> last_day_max_rr snowcover_max snowcover_days rain_days snow_days rh_mean_mon
#> 1 NA 10 21 4 6 0
#> 2 NA 18 16 4 7 0
#> 3 NA 2 3 3 8 0
#> 4 NA 0 0 6 4 0
#> 5 NA 0 0 9 0 0
#> 6 NA 0 0 16 0 0
#> ws_mean_mon cloud_mean_mon
#> 1 2.1 5.1
#> 2 2.2 6.6
#> 3 2.7 5.5
#> 4 2.1 3.5
#> 5 2.0 4.1
#> 6 1.8 5.3
# }