| ogimet_daily | R Documentation |
Downloading daily (meteorological) data from the Synop stations available in the https://www.ogimet.com/ repository. The data are processed only if temperature or precipitation fields are present.
ogimet_daily(
date = c(Sys.Date() - 30, Sys.Date()),
station = NA,
hour = 6,
allow_failure = TRUE,
...
)
date |
start and finish of date (e.g., date = c("2018-05-01","2018-07-01") ). By default last 30 days. |
station |
WMO ID of meteorological station(s). Character or numeric vector |
hour |
time for which the daily raport is generated. Set default as hour = 6 (i.e. 6 UTC) |
allow_failure |
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE |
... |
extra arguments that may be passed from wrapper top-level functions |
data.frame with historical meteorological data for the daily summaries
# downloading daily summaries for last 30 days. station: New York - La Guardia
new_york = ogimet_daily(station = 72503)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.