powered by
Downloading hourly (meteorological) data from the Synop stations available in the https://www.ogimet.com/ repository
ogimet_hourly( date = c(Sys.Date() - 30, Sys.Date()), station = 12330, precip_split = TRUE, allow_failure = TRUE )
data.frame with historical meteorological data for hourly time interval
start and finish of date (e.g., date = c("2018-05-01","2018-07-01") ); By default last 30 days are taken
WMO ID of meteorological station(s). Character or numeric vector
whether to split precipitation fields into 6/12/24h; default: TRUE
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
# \donttest{ # downloading hourly data for Poznan-Lawica, Poland for (default) last 30 days: poznan = ogimet_hourly(station = 12330) # }
Run the code above in your browser using DataLab