For IMGW-PIB stations different naming were used historically. For example, POZNAŃ and “POZNAŃ-ŁAWICA, thus both names should be used when searching for the station. This function finds all variants of station' names status information and expand the created object

find_all_station_names(station_name)

Arguments

station_name

character vector of station names

Value

character vector of station names with all variants of station's names

Examples

{
find_all_station_names(c("WARSZAWA", "POZNAŃ"))
}
#>  [1] "POZNAŃ"                    "POZNAŃ-ŁAWICA"            
#>  [3] "WARSZAWA"                  "WARSZAWA-BABICE"          
#>  [5] "WARSZAWA-BIELANY"          "WARSZAWA-CZAJKA"          
#>  [7] "WARSZAWA-CZERNIAKOWSKA"    "WARSZAWA-FILTRY"          
#>  [9] "WARSZAWA-KAWĘCZYN"         "WARSZAWA-OBSERWATORIUM"   
#> [11] "WARSZAWA-OBSERWATORIUM II" "WARSZAWA-OKĘCIE"