Learn R Programming

climate (version 1.4.1)

find_all_station_names: Find all variants of station' names

Description

For IMGW-PIB stations different naming were used historically. For example, POZNAŃ and ``POZNAŃ-ŁAWICA, thus both names should be used when searching for the station. This function finds all variants of station' names status information and expand the created object

Usage

find_all_station_names(station_name)

Value

character vector of station names with all variants of station's names

Arguments

station_name

character vector of station names

Examples

Run this code
{
find_all_station_names(c("WARSZAWA", "POZNAŃ"))
}

Run the code above in your browser using DataLab