Downloading daily, and monthly hydrological data from the measurement stations available in the danepubliczne.imgw.pl collection

hydro_imgw(interval, year, value = "H", station = NULL, ...)

Arguments

interval

temporal resolution of the data ("daily" or "monthly")

year

vector of years (e.g., 1966:2000)

value

type of data (can be: state - "H" (default), flow - "Q", or temperature - "T")

station

vector of hydrological stations danepubliczne.imgw.pl; can be given as station name with CAPITAL LETTERS (character) It accepts either names (characters in CAPITAL LETTERS) or stations' IDs (numeric)

...

other parameters that may be passed e.g. to the 'shortening' function that shortens column names

Value

A data.frame with columns describing the hydrological parameters (e.g. flow, water level) where each row represent a measurement, depending on the interval, at a given hour, month or year. If coords = TRUE additional two columns with geographic coordinates are added.

Examples

# \donttest{
  x = hydro_imgw("monthly", year = 1999)
#>     Your system locale is: C.UTF-8 which may cause trouble.
#>     Please consider changing it manually while working with climate, e.g.:
#>     Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8') 
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/MIES_publiczne_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/1999/mies_1999.zip
  head(x)
#>           id  X  Y       Data       PSNZWP   KDNRZK MCROKH MCMSCH MCWSKEX
#> 1  149180010 NA NA 1998-11-01 KRZYZANOWICE Odra (1)   1999      1       1
#> 2  149180010 NA NA 1998-11-01 KRZYZANOWICE Odra (1)   1999      1       2
#> 3  149180010 NA NA 1998-11-01 KRZYZANOWICE Odra (1)   1999      1       3
#> 4  149180010 NA NA 1998-12-01 KRZYZANOWICE Odra (1)   1999      2       1
#> 5  149180010 NA NA 1998-12-01 KRZYZANOWICE Odra (1)   1999      2       2
#> 6  149180010 NA NA 1998-12-01 KRZYZANOWICE Odra (1)   1999      2       3
#>   MCSTAN MCPRZP MCPTMP MCMSCK
#> 1    155   34.8     NA     11
#> 2    205   73.1     NA     11
#> 3    280  140.0     NA     11
#> 4    124   18.6     NA     12
#> 5    172   47.6     NA     12
#> 6    260  120.0     NA     12
# }