Downloading daily, and monthly hydrological data from the measurement stations available in the danepubliczne.imgw.pl collection

hydro_imgw(
  interval,
  year,
  coords = FALSE,
  value = "H",
  station = NULL,
  col_names = "short",
  ...
)

Arguments

interval

temporal resolution of the data ("daily" or "monthly")

year

vector of years (e.g., 1966:2000)

coords

add coordinates of the stations (logical value TRUE or FALSE)

value

type of data (can be: state - "H" (default), flow - "Q", or temperature - "T")

station

vector of hydrological stations danepubliczne.imgw.pl; can be given as station name with CAPITAL LETTERS (character) It accepts either names (characters in CAPITAL LETTERS) or stations' IDs (numeric)

col_names

three types of column names possible: "short" - default, values with shorten names, "full" - full English description, "polish" - original names in the dataset

...

other parameters that may be passed to the 'shortening' function that shortens column names

Value

A data.frame with columns describing the hydrological parameters (e.g. flow, water level) where each row represent a measurement, depending on the interval, at a given hour, month or year. If coords = TRUE additional two columns with geographic coordinates are added.

Examples

# \donttest{
  x = hydro_imgw("monthly", year = 1999)
#>     Your system locale is: C.UTF-8 which may cause trouble.
#>     Please consider changing it manually while working with climate, e.g.:
#>     Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8') 
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/MIES_publiczne_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_hydrologiczne/miesieczne/1999/mies_1999.zip
  head(x)
#>        PSKDSZS  PSNZWP   KDNRZK       Data MCROKH MCMSCH MCWSKEX MCSTAN MCPRZP
#> 433  151160130 ?CINAWA Odra (1) 1998-11-01   1999      1       1    245    178
#> 434  151160130 ?CINAWA Odra (1) 1998-11-01   1999      1       2    310    253
#> 435  151160130 ?CINAWA Odra (1) 1998-11-01   1999      1       3    366    329
#> 436  151160130 ?CINAWA Odra (1) 1998-12-01   1999      2       1    214    144
#> 437  151160130 ?CINAWA Odra (1) 1998-12-01   1999      2       2    266    202
#> 438  151160130 ?CINAWA Odra (1) 1998-12-01   1999      2       3    348    302
#>     MCPTMP MCMSCK
#> 433    1.8     11
#> 434    6.2     11
#> 435   10.4     11
#> 436    1.2     12
#> 437    2.2     12
#> 438    3.0     12
# }