A data.frame with columns describing the hydrological parameters
(e.g. flow, water level) where each row represent a measurement,
depending on the interval, at a given hour, month or year.
IMGW parameter columns carry a label attribute with the original metadata label.
If coords = TRUE additional two columns with geographic coordinates are added.