hydro_imgw_daily: Daily hydrological data
Description
Downloading daily hydrological data from the danepubliczne.imgw.pl collection
Usage
hydro_imgw_daily(year, station = NULL, allow_failure = TRUE, ...)
Value
data.frame with historical hydrological data for the daily time interval
Arguments
- year
vector of years (e.g., 1966:2000)
- station
name or ID of hydrological station(s).
It accepts names (characters in CAPITAL LETTERS) or stations' IDs (numeric)
- allow_failure
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
- ...
other parameters that may be passed to the 'shortening' function that shortens column names
Examples
Run this code# \donttest{
daily = hydro_imgw_daily(year = 2000)
# }
Run the code above in your browser using DataLab