Downloading hourly, daily, and monthly meteorological data from the SYNOP / CLIMATE / PRECIP stations, or sub-hourly (10-minute) telemetry data from the automated network, all available in the danepubliczne.imgw.pl collection.

meteo_imgw(
  interval = NULL,
  rank = "synop",
  year,
  status = FALSE,
  coords = FALSE,
  station = NULL,
  col_names = "short",
  parameters = NULL,
  ...
)

Arguments

interval

temporal resolution of the data: "hourly", "daily", or "monthly". Not used when rank = "telemetry" (telemetry data are always at 10-minute intervals). Defaults to NULL, which is only valid together with rank = "telemetry".

rank

rank of the stations: "synop" (default), "climate", "precip", or "telemetry". Use "telemetry" for the automated IMGW datastore network (data available since 2008).

year

vector of years (e.g., 1966:2000). For rank = "telemetry" all years must be >= 2008.

status

leave the columns with measurement and observation statuses (default FALSE — status columns are deleted). Not used when rank = "telemetry".

coords

add coordinates of the station (logical value TRUE or FALSE). Default FALSE.

station

name of meteorological station(s). For ranks "synop", "climate", "precip": station name(s) in CAPITAL LETTERS. Please note that station names may change over time — sometimes two names are required, e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA"). For rank = "telemetry": station name(s) as listed by stations_meteo_imgw_telemetry(). NULL (default) downloads all available stations.

col_names

column name style: "short" (default), "full" (English descriptions), or "polish" (original dataset names). Not used when rank = "telemetry".

parameters

character vector of parameter codes to download. Only used when rank = "telemetry". NULL (default) downloads all available parameters. Accepted values: "wd", "t2m", "t0m", "rr_24h", "rr_1h", "rr_10min", "ws", "ws_max", "gust", "rh", "water_in_snow".

...

other parameters passed to the column-shortening function. Not used when rank = "telemetry".

Value

A data.frame with meteorological parameters where each row is a measurement. For ranks "synop", "climate", "precip": measurements at a given hour, day, or month, depending on interval. If coords = TRUE two additional coordinate columns are appended. For rank = "telemetry": a data.table with 10-minute interval observations (not expert-validated). If coords = TRUE columns name, lon, lat, and alt are appended.

Examples

# \donttest{
  x = meteo_imgw("monthly", year = 2018, coords = TRUE)
#>     Your system locale is: C.UTF-8 which may cause trouble.
#>     Please consider changing it manually while working with climate, e.g.:
#>     Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8') 
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/2018/2018_m_s.zip
  head(x)
#>          id        X        Y       station   yy mm
#> 1 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  1
#> 2 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  2
#> 3 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  3
#> 4 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  4
#> 5 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  5
#> 6 349190600 19.00234 49.80671 BIELSKO-BIALA 2018  6
#>   Absolutna maksymalna temperatura powietrza [°C]
#> 1                                            11.6
#> 2                                             7.2
#> 3                                            16.5
#> 4                                            26.7
#> 5                                            28.0
#> 6                                            29.5
#>   Srednia maksymalna temperatura powietrza [°C]
#> 1                                           5.0
#> 2                                          -1.4
#> 3                                           4.8
#> 4                                          20.3
#> 5                                          21.3
#> 6                                          22.7
#>   Absolutna minimalna temperatura powietrza [°C]
#> 1                                           -7.7
#> 2                                          -15.5
#> 3                                          -17.2
#> 4                                           -1.0
#> 5                                            5.1
#> 6                                            8.1
#>   Srednia minimalna temperatura powietrza [°C]
#> 1                                         -0.4
#> 2                                         -6.0
#> 3                                         -3.0
#> 4                                          8.2
#> 5                                         10.6
#> 6                                         13.5
#>   Srednia miesieczna temperatura powietrza [°C]
#> 1                                           2.3
#> 2                                          -3.7
#> 3                                           1.0
#> 4                                          14.3
#> 5                                          16.2
#> 6                                          17.6
#>   Minimalna temperatura powietrza przy gruncie [°C] rr_monthly
#> 1                                             -10.8       23.5
#> 2                                             -23.3       34.1
#> 3                                             -21.9       28.5
#> 4                                              -1.7       10.3
#> 5                                               2.2       91.1
#> 6                                               6.1      135.5
#>   Maksymalna dobowa suma opadow w miesiacu [mm] first_day_max_rr
#> 1                                           6.5                8
#> 2                                           9.5                4
#> 3                                          10.1               16
#> 4                                           3.5               23
#> 5                                          19.5               17
#> 6                                          30.4                2
#>   last_day_max_rr insolation_monthly snowcover_max snowcover_days rain_days
#> 1              NA               58.8             4              5         7
#> 2              NA               47.0            19             25         0
#> 3              NA              110.7            15             14         5
#> 4              NA              218.2             0              0         7
#> 5              NA              247.1             0              0        14
#> 6              NA              164.1             0              0        16
#>   snow_days r_s_days hail_days fog_days fogginess_days rime_days glaze_days
#> 1        10        4         0        5             25         0          0
#> 2        16        4         0        7             28         0          1
#> 3         7        2         0        2             24         0          0
#> 4         1        1         0        1              6         0          0
#> 5         0        0         1        1             11         0          0
#> 6         1        0         0        2             15         0          0
#>   snowstorm_low_days snowstorm_high_days Liczba dni ze zmetnieniem opalizujacym
#> 1                  0                   0                                      0
#> 2                  6                   1                                      2
#> 3                  2                   0                                      7
#> 4                  0                   0                                      0
#> 5                  0                   0                                      0
#> 6                  0                   0                                      0
#>   thunder_days dew_days hoarfrost_days NA. NA..1 cloud_mean_mon ws_mean_mon
#> 1            2        0              0   9    NA            6.4         4.6
#> 2            0        0              0   3    NA            6.8         2.9
#> 3            0        0              2   5    NA            5.5         3.6
#> 4            0        1             17   2    NA            4.2         3.8
#> 5            0        9             26   0    NA            4.4         3.1
#> 6            0        9             15   0    NA            5.7         2.6
#>   vapor_press_mean_mon rh_mean_mon press_mean_mon
#> 1                  5.8        80.0          967.9
#> 2                  4.1        83.8          969.5
#> 3                  5.1        72.5          959.8
#> 4                  9.0        56.7          967.9
#> 5                 12.3        68.4          969.9
#> 6                 14.8        74.2          968.6
#>   Srednie miesieczne cisnienie na poziomie morza [hPa] rr_daytime rr_nightime
#> 1                                               1017.2       13.5        10.0
#> 2                                               1019.9       17.4        16.7
#> 3                                               1008.9       14.1        14.4
#> 4                                               1015.0        5.3         5.0
#> 5                                               1016.8       40.6        50.5
#> 6                                               1015.2       45.7        89.8

  # Telemetry (10-minute) data from automated stations (available since 2008):
  tel = meteo_imgw(rank = "telemetry", year = 2022,
                   parameters = "t2m",
                   station = "HALA GĄSIENICOWA")
  head(tel)
#> Key: <id>
#>           id           date_time   t2m
#>        <int>              <POSc> <num>
#> 1: 349200628 2022-01-01 00:00:00   3.2
#> 2: 349200628 2022-01-01 00:10:00   3.4
#> 3: 349200628 2022-01-01 00:20:00   3.2
#> 4: 349200628 2022-01-01 00:30:00   3.3
#> 5: 349200628 2022-01-01 00:40:00   3.1
#> 6: 349200628 2022-01-01 00:50:00   2.8
# }