Downloading hourly, daily, and monthly meteorological data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection.
meteo_imgw(
interval,
rank = "synop",
year,
status = FALSE,
coords = FALSE,
station = NULL,
col_names = "short",
...
)temporal resolution of the data ("hourly", "daily", "monthly")
rank of the stations: "synop" (default), "climate" or "precip"
vector of years (e.g., 1966:2000)
leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted)
add coordinates of the station (logical value TRUE or FALSE)
name of meteorological station(s).
It accepts names (characters in CAPITAL LETTERS). Stations' IDs (numeric) are no longer supported.
Please note that station names may change over time and thus sometimes 2 names
are required in some cases, e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA").
three types of column names possible: "short" - default, values with shorten names, "full" - full English description, "polish" - original names in the dataset
other parameters that may be passed to the 'shortening' function that shortens column names
A data.frame with columns describing the meteorological parameters
(e.g. temperature, wind speed, precipitation) where each row represent a measurement,
depending on the interval, at a given hour, month or year.
If coords = TRUE additional two
columns with geographic coordinates are added.
# \donttest{
x = meteo_imgw("monthly", year = 2018, coords = TRUE)
#> Your system locale is: C.UTF-8 which may cause trouble.
#> Please consider changing it manually while working with climate, e.g.:
#> Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8')
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/2018/2018_m_s.zip
head(x)
#> Key: <id>
#> id X Y POST ROK MC TMAX TMXS TMIN
#> <int> <num> <num> <char> <int> <int> <num> <num> <num>
#> 1: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 1 11.6 5.0 -7.7
#> 2: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 2 7.2 -1.4 -15.5
#> 3: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 3 16.5 4.8 -17.2
#> 4: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 4 26.7 20.3 -1.0
#> 5: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 5 28.0 21.3 5.1
#> 6: 349190600 19.00234 49.80671 BIELSKO-BIALA 2018 6 29.5 22.7 8.1
#> TMNS STM TMNG SUMM OPMX DN1 DN2 SUUS PKSN PSDN DESD SNID
#> <num> <num> <num> <num> <num> <int> <int> <num> <int> <int> <int> <int>
#> 1: -0.4 2.3 -10.8 23.5 6.5 8 NA 58.8 4 5 7 10
#> 2: -6.0 -3.7 -23.3 34.1 9.5 4 NA 47.0 19 25 0 16
#> 3: -3.0 1.0 -21.9 28.5 10.1 16 NA 110.7 15 14 5 7
#> 4: 8.2 14.3 -1.7 10.3 3.5 23 NA 218.2 0 0 7 1
#> 5: 10.6 16.2 2.2 91.1 19.5 17 NA 247.1 0 0 14 0
#> 6: 13.5 17.6 6.1 135.5 30.4 2 NA 164.1 0 0 16 1
#> DSND GRDD MGLD ZAMD SADD GOLD ZAND ZAWD ZMED BURD ROSD SZRD
#> <int> <int> <int> <int> <int> <int> <int> <int> <int> <int> <int> <int>
#> 1: 4 0 5 25 0 0 0 0 0 2 0 0
#> 2: 4 0 7 28 0 1 6 1 2 0 0 0
#> 3: 2 0 2 24 0 0 2 0 7 0 0 2
#> 4: 1 0 1 6 0 0 0 0 0 0 1 17
#> 5: 0 1 1 11 0 0 0 0 0 0 9 26
#> 6: 0 0 2 15 0 0 0 0 0 0 9 15
#> NA. NA..1 NOS FWS TEMP CPW WLGS PPPS PPPM WODZ WONO
#> <int> <int> <num> <num> <num> <num> <num> <num> <num> <num> <num>
#> 1: 9 NA 6.4 4.6 2.3 5.8 80.0 967.9 1017.2 13.5 10.0
#> 2: 3 NA 6.8 2.9 -3.7 4.1 83.8 969.5 1019.9 17.4 16.7
#> 3: 5 NA 5.5 3.6 1.0 5.1 72.5 959.8 1008.9 14.1 14.4
#> 4: 2 NA 4.2 3.8 14.3 9.0 56.7 967.9 1015.0 5.3 5.0
#> 5: 0 NA 4.4 3.1 16.2 12.3 68.4 969.9 1016.8 40.6 50.5
#> 6: 0 NA 5.7 2.6 17.5 14.8 74.2 968.6 1015.2 45.7 89.8
# }