| meteo_imgw | R Documentation |
Downloading hourly, daily, and monthly meteorological data from the SYNOP / CLIMATE / PRECIP stations, or sub-hourly (10-minute) telemetry data from the automated network, all available in the danepubliczne.imgw.pl collection.
meteo_imgw(
interval = NULL,
rank = "synop",
year,
status = FALSE,
coords = FALSE,
station = NULL,
parameters = NULL,
...
)
interval |
temporal resolution of the data: |
rank |
rank of the stations: |
year |
vector of years (e.g., |
status |
leave the columns with measurement and observation statuses
(default |
coords |
add coordinates of the station (logical value |
station |
name of meteorological station(s).
For ranks |
parameters |
character vector of parameter codes to download.
Only used when |
... |
other parameters passed to the column-shortening function. Not used when
|
A data.frame with meteorological parameters where each row is a measurement.
For ranks "synop", "climate", "precip": measurements at a given hour, day, or month,
depending on interval. If coords = TRUE two additional coordinate columns are appended.
IMGW parameter columns also carry a label attribute with the original Polish metadata label.
For rank = "telemetry": a data.table with 10-minute interval observations (not
expert-validated). If coords = TRUE columns name, lon, lat, and alt are appended.
x = meteo_imgw("monthly", year = 2018, coords = TRUE)
head(x)
# Telemetry (10-minute) data from automated stations (available since 2008):
tel = meteo_imgw(rank = "telemetry", year = 2022,
parameters = "t2m",
station = "HALA GĄSIENICOWA")
head(tel)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.