- interval
temporal resolution of the data: "hourly", "daily", or "monthly".
Not used when rank = "telemetry" (telemetry data are always at 10-minute intervals).
Defaults to NULL, which is only valid together with rank = "telemetry".
- rank
rank of the stations: "synop" (default), "climate", "precip", or "telemetry".
Use "telemetry" for the automated IMGW datastore network (data available since 2008).
- year
vector of years (e.g., 1966:2000).
For rank = "telemetry" all years must be >= 2008.
- status
leave the columns with measurement and observation statuses
(default FALSE — status columns are deleted). Not used when rank = "telemetry".
- coords
add coordinates of the station (logical value TRUE or FALSE).
Default FALSE.
- station
name of meteorological station(s).
For ranks "synop", "climate", "precip": station name(s) in CAPITAL LETTERS.
Please note that station names may change over time — sometimes two names are required,
e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA").
For rank = "telemetry": station name(s) as listed by stations_meteo_imgw_telemetry().
NULL (default) downloads all available stations.
- parameters
character vector of parameter codes to download.
Only used when rank = "telemetry". NULL (default) downloads all available parameters.
Accepted values: "wd", "t2m", "t0m", "rr_24h", "rr_1h", "rr_10min",
"ws", "ws_max", "gust", "rh", "water_in_snow".
- ...
other parameters passed to the column-shortening function. Not used when
rank = "telemetry".