- rank
rank of the stations: "synop" (default), "climate", or "precip"
- year
vector of years (e.g., 1966:2000)
- status
leave the columns with measurement and observation statuses
(default status = FALSE - i.e. the status columns are deleted)
- coords
add coordinates of the station (logical value TRUE or FALSE)
- station
name of meteorological station(s).
It accepts vector of names (characters in CAPITAL LETTERS);
Important: Some stations may have changed names over time in the IMGW-PIB
database and thus providing both names is needed
(e.g. station = c("POZNAŃ", "POZNAŃ-ŁAWICA", "WARSZAWA", "WARSZAWA-OKĘCIE")).
Stations' IDs (numeric) are no longer valid
- allow_failure
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
- ...
other parameters that may be passed to the 'shortening' function that
shortens column names