Downloading daily (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection
meteo_imgw_daily(
rank = "synop",
year,
status = FALSE,
coords = FALSE,
station = NULL,
col_names = "short",
allow_failure = TRUE,
...
)data.frame with a daily meteorological measurements
rank of the stations: "synop" (default), "climate", or "precip"
vector of years (e.g., 1966:2000)
leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted)
add coordinates of the station (logical value TRUE or FALSE)
name of meteorological station(s).
It accepts vector of names (characters in CAPITAL LETTERS);
Important: Some stations may have changed names over time in the IMGW-PIB
database and thus providing both names is needed
(e.g. station = c("POZNAŃ", "POZNAŃ-ŁAWICA", "WARSZAWA", "WARSZAWA-OKĘCIE")).
Stations' IDs (numeric) are no longer valid
three types of column names possible: "short" - default, values with shorten names, "full" - full English description, "polish" - original names in the dataset
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
other parameters that may be passed to the 'shortening' function that shortens column names
# \donttest{
daily = meteo_imgw_daily(rank = "climate", year = 2000)
# }
Run the code above in your browser using DataLab