Downloading monthly (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection

meteo_imgw_monthly(
  rank = "synop",
  year,
  status = FALSE,
  coords = FALSE,
  station = NULL,
  allow_failure = TRUE,
  ...
)

Arguments

rank

rank of the stations: "synop" (default), "climate", or "precip"

year

vector of years (e.g., 1966:2000)

status

leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted)

coords

add coordinates of the station (logical value TRUE or FALSE)

station

name of meteorological station(s). It accepts names (characters in CAPITAL LETTERS). Stations' IDs (numeric) are no longer supported. Please note that station names may change over time and thus sometimes 2 names are required in some cases, e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA").

allow_failure

logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE

...

other parameters that may be passed to the 'shortening' function that shortens column names

Value

meteorological data with monthly summaries

Examples

# \donttest{
monthly = meteo_imgw_monthly(rank = "climate", year = 1969)
#>     Your system locale is: C.UTF-8 which may cause trouble.
#>     Please consider changing it manually while working with climate, e.g.:
#>     Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8') 
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/1966_1970/1966_1970_m_k.zip
head(monthly)
#>          id  station   yy mm tmax_abs tmax_mean tmin_abs tmin_mean t2m_mean_mon
#> 1 249180010 PSZCZYNA 1969  1      9.5      -1.3    -20.0      -9.3         -5.1
#> 2 249180010 PSZCZYNA 1969  2      7.4       0.4    -16.6      -4.7         -2.3
#> 3 249180010 PSZCZYNA 1969  3     11.4       2.5    -10.6      -3.5         -0.8
#> 4 249180010 PSZCZYNA 1969  4     27.5      13.1     -4.4       2.0          7.1
#> 5 249180010 PSZCZYNA 1969  5     30.0      21.3      2.0       9.0         14.8
#> 6 249180010 PSZCZYNA 1969  6     28.9      20.9      6.1      10.5         15.4
#>   tmin_soil rr_monthly rr_max_daily first_day_max_rr last_day_max_rr
#> 1     -22.4       34.9         12.0               23              NA
#> 2     -17.5       47.2         15.9                8              NA
#> 3     -11.3       44.8         10.1               11              NA
#> 4      -6.2       15.7          4.0                1              NA
#> 5      -0.1       69.2         30.0               29              NA
#> 6       4.4      101.2         35.0               21              NA
#>   snowcover_max snowcover_days rain_days snow_days rh_mean_mon ws_mean_mon
#> 1            10             21         4         6           0         2.1
#> 2            18             16         4         7           0         2.2
#> 3             2              3         3         8           0         2.7
#> 4             0              0         6         4           0         2.1
#> 5             0              0         9         0           0         2.0
#> 6             0              0        16         0           0         1.8
#>   cloud_mean_mon
#> 1            5.1
#> 2            6.6
#> 3            5.5
#> 4            3.5
#> 5            4.1
#> 6            5.3

# }