Downloading monthly (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection
meteo_imgw_monthly(
rank = "synop",
year,
status = FALSE,
coords = FALSE,
station = NULL,
col_names = "short",
allow_failure = TRUE,
...
)rank of the stations: "synop" (default), "climate", or "precip"
vector of years (e.g., 1966:2000)
leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted)
add coordinates of the station (logical value TRUE or FALSE)
name of meteorological station(s).
It accepts names (characters in CAPITAL LETTERS). Stations' IDs (numeric) are no longer supported.
Please note that station names may change over time and thus sometimes 2 names
are required in some cases, e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA").
three types of column names possible: "short" - default, values with shorten names, "full" - full English description, "polish" - original names in the dataset
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
other parameters that may be passed to the 'shortening' function that shortens column names
meteorological data with monthly summaries
# \donttest{
monthly = meteo_imgw_monthly(rank = "climate", year = 1969)
#> Your system locale is: C.UTF-8 which may cause trouble.
#> Please consider changing it manually while working with climate, e.g.:
#> Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8')
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/k_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/klimat/1966_1970/1966_1970_m_k.zip
head(monthly)
#> id station yy mm Absolutna maksymalna temperatura powietrza [°C]
#> 1 249180010 PSZCZYNA 1969 1 9.5
#> 2 249180010 PSZCZYNA 1969 2 7.4
#> 3 249180010 PSZCZYNA 1969 3 11.4
#> 4 249180010 PSZCZYNA 1969 4 27.5
#> 5 249180010 PSZCZYNA 1969 5 30.0
#> 6 249180010 PSZCZYNA 1969 6 28.9
#> Srednia maksymalna temperatura powietrza [°C]
#> 1 -1.3
#> 2 0.4
#> 3 2.5
#> 4 13.1
#> 5 21.3
#> 6 20.9
#> Absolutna minimalna temperatura powietrza [°C]
#> 1 -20.0
#> 2 -16.6
#> 3 -10.6
#> 4 -4.4
#> 5 2.0
#> 6 6.1
#> Srednia minimalna temperatura powietrza [°C]
#> 1 -9.3
#> 2 -4.7
#> 3 -3.5
#> 4 2.0
#> 5 9.0
#> 6 10.5
#> Srednia miesieczna temperatura powietrza [°C]
#> 1 -5.1
#> 2 -2.3
#> 3 -0.8
#> 4 7.1
#> 5 14.8
#> 6 15.4
#> Minimalna temperatura powietrza przy gruncie [°C] rr_monthly
#> 1 -22.4 34.9
#> 2 -17.5 47.2
#> 3 -11.3 44.8
#> 4 -6.2 15.7
#> 5 -0.1 69.2
#> 6 4.4 101.2
#> Maksymalna dobowa suma opadow w miesiacu [mm] first_day_max_rr
#> 1 12.0 23
#> 2 15.9 8
#> 3 10.1 11
#> 4 4.0 1
#> 5 30.0 29
#> 6 35.0 21
#> last_day_max_rr snowcover_max snowcover_days rain_days snow_days rh_mean_mon
#> 1 NA 10 21 4 6 0
#> 2 NA 18 16 4 7 0
#> 3 NA 2 3 3 8 0
#> 4 NA 0 0 6 4 0
#> 5 NA 0 0 9 0 0
#> 6 NA 0 0 16 0 0
#> ws_mean_mon cloud_mean_mon
#> 1 2.1 5.1
#> 2 2.2 6.6
#> 3 2.7 5.5
#> 4 2.1 3.5
#> 5 2.0 4.1
#> 6 1.8 5.3
# a descriptive (long) column names:
monthly2 = meteo_imgw_monthly(
rank = "synop", year = 2018,
col_names = "full"
)
#> Your system locale is: C.UTF-8 which may cause trouble.
#> Please consider changing it manually while working with climate, e.g.:
#> Sys.setlocale(category = 'LC_ALL', locale = 'en_US.UTF-8')
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_d_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/s_m_t_format.txt
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/
#> https://danepubliczne.imgw.pl/data/dane_pomiarowo_obserwacyjne/dane_meteorologiczne/miesieczne/synop/2018/2018_m_s.zip
head(monthly2)
#> ID Station Year Month
#> 1 349190600 BIELSKO-BIALA 2018 1
#> 2 349190600 BIELSKO-BIALA 2018 2
#> 3 349190600 BIELSKO-BIALA 2018 3
#> 4 349190600 BIELSKO-BIALA 2018 4
#> 5 349190600 BIELSKO-BIALA 2018 5
#> 6 349190600 BIELSKO-BIALA 2018 6
#> Absolutna maksymalna temperatura powietrza [°C]
#> 1 11.6
#> 2 7.2
#> 3 16.5
#> 4 26.7
#> 5 28.0
#> 6 29.5
#> Srednia maksymalna temperatura powietrza [°C]
#> 1 5.0
#> 2 -1.4
#> 3 4.8
#> 4 20.3
#> 5 21.3
#> 6 22.7
#> Absolutna minimalna temperatura powietrza [°C]
#> 1 -7.7
#> 2 -15.5
#> 3 -17.2
#> 4 -1.0
#> 5 5.1
#> 6 8.1
#> Srednia minimalna temperatura powietrza [°C]
#> 1 -0.4
#> 2 -6.0
#> 3 -3.0
#> 4 8.2
#> 5 10.6
#> 6 13.5
#> Srednia miesieczna temperatura powietrza [°C]
#> 1 2.3
#> 2 -3.7
#> 3 1.0
#> 4 14.3
#> 5 16.2
#> 6 17.6
#> Minimalna temperatura powietrza przy gruncie [°C]
#> 1 -10.8
#> 2 -23.3
#> 3 -21.9
#> 4 -1.7
#> 5 2.2
#> 6 6.1
#> Total monthly precipitation [mm]
#> 1 23.5
#> 2 34.1
#> 3 28.5
#> 4 10.3
#> 5 91.1
#> 6 135.5
#> Maksymalna dobowa suma opadow w miesiacu [mm]
#> 1 6.5
#> 2 9.5
#> 3 10.1
#> 4 3.5
#> 5 19.5
#> 6 30.4
#> First day with maximum precipitation Last day with maximum precipitation
#> 1 8 NA
#> 2 4 NA
#> 3 16 NA
#> 4 23 NA
#> 5 17 NA
#> 6 2 NA
#> Total monthly insolation [hours] Maximum daily snow cover [cm]
#> 1 58.8 4
#> 2 47.0 19
#> 3 110.7 15
#> 4 218.2 0
#> 5 247.1 0
#> 6 164.1 0
#> Days with snow cover Days with rain Days with snow Days with sleet
#> 1 5 7 10 4
#> 2 25 0 16 4
#> 3 14 5 7 2
#> 4 0 7 1 1
#> 5 0 14 0 0
#> 6 0 16 1 0
#> Days with hail Days with fog Days with fogginess Days with rime
#> 1 0 5 25 0
#> 2 0 7 28 0
#> 3 0 2 24 0
#> 4 0 1 6 0
#> 5 1 1 11 0
#> 6 0 2 15 0
#> Days with glaze Days with low snowstorm Days with high snowstorm
#> 1 0 0 0
#> 2 1 6 1
#> 3 0 2 0
#> 4 0 0 0
#> 5 0 0 0
#> 6 0 0 0
#> Liczba dni ze zmetnieniem opalizujacym Days with thunderstorm Days with dew
#> 1 0 2 0
#> 2 2 0 0
#> 3 7 0 0
#> 4 0 0 1
#> 5 0 0 9
#> 6 0 0 9
#> Days with hoarfrost NA. NA..1 Monthly mean total cloudiness [hPa]
#> 1 0 9 NA 6.4
#> 2 0 3 NA 6.8
#> 3 2 5 NA 5.5
#> 4 17 2 NA 4.2
#> 5 26 0 NA 4.4
#> 6 15 0 NA 5.7
#> Monthly mean wind speed [m/s] Monthly mean vapour pressure [hPa]
#> 1 4.6 5.8
#> 2 2.9 4.1
#> 3 3.6 5.1
#> 4 3.8 9.0
#> 5 3.1 12.3
#> 6 2.6 14.8
#> Monthly mean relative humidity [%]
#> 1 80.0
#> 2 83.8
#> 3 72.5
#> 4 56.7
#> 5 68.4
#> 6 74.2
#> Monthly mean pressure at station level [hPa]
#> 1 967.9
#> 2 969.5
#> 3 959.8
#> 4 967.9
#> 5 969.9
#> 6 968.6
#> Srednie miesieczne cisnienie na poziomie morza [hPa]
#> 1 1017.2
#> 2 1019.9
#> 3 1008.9
#> 4 1015.0
#> 5 1016.8
#> 6 1015.2
#> Total precipitation during day [mm] Total precipitation during night [mm]
#> 1 13.5 10.0
#> 2 17.4 16.7
#> 3 14.1 14.4
#> 4 5.3 5.0
#> 5 40.6 50.5
#> 6 45.7 89.8
# }