Learn R Programming

climate (version 1.4.1)

meteo_imgw_monthly: Monthly IMGW meteorological data

Description

Downloading monthly (meteorological) data from the SYNOP / CLIMATE / PRECIP stations available in the danepubliczne.imgw.pl collection

Usage

meteo_imgw_monthly(
  rank = "synop",
  year,
  status = FALSE,
  coords = FALSE,
  station = NULL,
  allow_failure = TRUE,
  ...
)

Value

meteorological data with monthly summaries

Arguments

rank

rank of the stations: "synop" (default), "climate", or "precip"

year

vector of years (e.g., 1966:2000)

status

leave the columns with measurement and observation statuses (default status = FALSE - i.e. the status columns are deleted)

coords

add coordinates of the station (logical value TRUE or FALSE)

station

name of meteorological station(s). It accepts names (characters in CAPITAL LETTERS). Stations' IDs (numeric) are no longer supported. Please note that station names may change over time and thus sometimes 2 names are required in some cases, e.g. c("POZNAŃ", "POZNAŃ-ŁAWICA").

allow_failure

logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE

...

other parameters that may be passed to the 'shortening' function that shortens column names

Examples

Run this code
# \donttest{
monthly = meteo_imgw_monthly(rank = "climate", year = 1969)
head(monthly)

# }

Run the code above in your browser using DataLab