ogimet_daily: Scrapping daily meteorological (Synop) data from the Ogimet webpage
Description
Downloading daily (meteorological) data from the Synop stations available in the https://www.ogimet.com/ repository.
The data are processed only if temperature or precipitation fields are present.
Usage
ogimet_daily(
date = c(Sys.Date() - 30, Sys.Date()),
station = NA,
hour = 6,
allow_failure = TRUE,
...
)
Value
data.frame with historical meteorological data for the daily summaries
Arguments
- date
start and finish of date (e.g., date = c("2018-05-01","2018-07-01") ). By default last 30 days.
- station
WMO ID of meteorological station(s). Character or numeric vector
- hour
time for which the daily raport is generated. Set default as hour = 6 (i.e. 6 UTC)
- allow_failure
logical - whether to proceed or stop on failure. By default set to TRUE (i.e. don't stop on error). For debugging purposes change to FALSE
- ...
extra arguments that may be passed from wrapper top-level functions
Examples
Run this code# \donttest{
# downloading daily summaries for last 30 days. station: New York - La Guardia
new_york = ogimet_daily(station = 72503)
# }
Run the code above in your browser using DataLab